@@ -1,4 +1,4 @@
-package Pcore::API::Whois v0.1.2;
+package Pcore::API::Whois v0.1.3;
 
 use Pcore -dist, -class;
 use Pcore::API::Whois::Server;
@@ -43,7 +43,11 @@ sub search ( $self, $domain, $cb = undef ) {
     }
 
     if ( !$server_host ) {
-        my $res = Pcore::API::Whois::Response->new( { status => $WHOIS_NOT_SUPPORTED, reason => $Pcore::API::Whois::Response::STATUS_REASON->{$WHOIS_NOT_SUPPORTED} } );
+        my $res = Pcore::API::Whois::Response->new(
+            {   status => $WHOIS_NOT_SUPPORTED,
+                reason => $Pcore::API::Whois::Response::STATUS_REASON->{$WHOIS_NOT_SUPPORTED}
+            }
+        );
 
         $cb->($res) if $cb;
 
@@ -54,7 +58,11 @@ sub search ( $self, $domain, $cb = undef ) {
             {   host => $server_host,
                 cb   => sub($server) {
                     if ( !$server || !$server->is_supported ) {
-                        my $res = Pcore::API::Whois::Response->new( { status => $WHOIS_NOT_SUPPORTED, reason => $Pcore::API::Whois::Response::STATUS_REASON->{$WHOIS_NOT_SUPPORTED} } );
+                        my $res = Pcore::API::Whois::Response->new(
+                            {   status => $WHOIS_NOT_SUPPORTED,
+                                reason => $Pcore::API::Whois::Response::STATUS_REASON->{$WHOIS_NOT_SUPPORTED}
+                            }
+                        );
 
                         $cb->($res) if $cb;
 
@@ -150,11 +158,11 @@ sub export_supported_pub_suffixes ($self) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 16, 118, 135, 139    | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## |    3 | 16, 126, 143, 147    | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    3 | 20                   | Subroutines::ProhibitExcessComplexity - Subroutine "search" with high complexity score (27)                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 72, 84               | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
+## |    3 | 80, 92               | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
