@@ -104,9 +104,9 @@ sub _build_exceed_re ($self) {
 sub _build_notfound_re ($self) {
     my $re;
 
-    push $re->@*, qr/$Pcore::API::Whois::DB->{notfound}->{$self->{host}}/smo if $Pcore::API::Whois::DB->{notfound}->{ $self->{host} };
+    push $re->@*, qr/$Pcore::API::Whois::DB->{notfound}->{$self->{host}}/sm if $Pcore::API::Whois::DB->{notfound}->{ $self->{host} };
 
-    push $re->@*, qr/$Net::Whois::Raw::Data::notfound{$self->{host}}/smo if $Net::Whois::Raw::Data::notfound{ $self->{host} };
+    push $re->@*, qr/$Net::Whois::Raw::Data::notfound{$self->{host}}/sm if $Net::Whois::Raw::Data::notfound{ $self->{host} };
 
     return $re;
 }
@@ -155,7 +155,8 @@ sub request ( $self, $domain_ascii, @ ) {
 
             $cb->(
                 Pcore::API::Whois::Response->new(
-                    {   status => $WHOIS_NETWORK_ERROR,
+                    {   server => $self,
+                        status => $WHOIS_NETWORK_ERROR,
                         reason => $reason,
                     }
                 )
@@ -188,7 +189,8 @@ sub request ( $self, $domain_ascii, @ ) {
                     # empty content = network error
                     if ( !defined $buf_ref->$* ) {
                         $res = Pcore::API::Whois::Response->new(
-                            {   status => $WHOIS_NO_CONTENT,
+                            {   server => $self,
+                                status => $WHOIS_NO_CONTENT,
                                 reason => $Pcore::API::Whois::Response::STATUS_REASON->{$WHOIS_NO_CONTENT},
                             }
                         );
@@ -196,7 +198,11 @@ sub request ( $self, $domain_ascii, @ ) {
                     else {
                         decode_eol( $buf_ref->$* );
 
-                        $res = Pcore::API::Whois::Response->new( { content => $buf_ref } );
+                        $res = Pcore::API::Whois::Response->new(
+                            {   server  => $self,
+                                content => $buf_ref
+                            }
+                        );
                     }
 
                     $cb->($res);
